pub struct Schedule<L> {
pub dag: DAG<Ref<L>>,
}Expand description
A task schedule based on a DAG of task nodes.
Fields
dag: DAG<Ref<L>>Implementations
Sourceimpl<L> Schedule<L>
impl<L> Schedule<L>
Sourceimpl<L> Schedule<L>
impl<L> Schedule<L>
Sourcepub fn add_node<I, O, T, D>(
&mut self,
task: T,
deps: D,
label: L,
) -> Arc<Node<I, O, L>>
pub fn add_node<I, O, T, D>( &mut self, task: T, deps: D, label: L, ) -> Arc<Node<I, O, L>>
Add a new task to the graph.
Dependencies for the task must be references to
tasks that have already been added to the task
graph (Arc
pub fn add_closure<C, I, O, D>( &mut self, closure: C, deps: D, label: L, ) -> Arc<Node<I, O, L>>
pub fn add_input<O>(&mut self, input: O, label: L) -> Arc<Node<(), O, L>>
Sourcepub fn fail_dependants(&mut self, root: Idx, dependencies: bool)
pub fn fail_dependants(&mut self, root: Idx, dependencies: bool)
Marks all dependants as failed.
Optionally also marks all dependencies as failed if they have no pending dependants.
TODO: is this correct and sufficient? TODO: really test this…
pub fn ready(&self) -> impl Iterator<Item = Idx> + '_
pub fn running(&self) -> impl Iterator<Item = Idx> + '_